// This file has been generated by Py++.

#ifndef CvMemStorage_hpp__pyplusplus_wrapper
#define CvMemStorage_hpp__pyplusplus_wrapper

void register_CvMemStorage_class();

#endif//CvMemStorage_hpp__pyplusplus_wrapper
