// This file has been generated by Py++.

#ifndef FernClassifier_hpp__pyplusplus_wrapper
#define FernClassifier_hpp__pyplusplus_wrapper

void register_FernClassifier_class();

#endif//FernClassifier_hpp__pyplusplus_wrapper
