// This file has been generated by Py++.

#ifndef RotatedRect_hpp__pyplusplus_wrapper
#define RotatedRect_hpp__pyplusplus_wrapper

void register_RotatedRect_class();

#endif//RotatedRect_hpp__pyplusplus_wrapper
