// This file has been generated by Py++.

#ifndef CvVectors_hpp__pyplusplus_wrapper
#define CvVectors_hpp__pyplusplus_wrapper

void register_CvVectors_class();

#endif//CvVectors_hpp__pyplusplus_wrapper
