// This file has been generated by Py++.

#ifndef BackgroundSubtractorMOG_hpp__pyplusplus_wrapper
#define BackgroundSubtractorMOG_hpp__pyplusplus_wrapper

void register_BackgroundSubtractorMOG_class();

#endif//BackgroundSubtractorMOG_hpp__pyplusplus_wrapper
