// This file has been generated by Py++.

#ifndef FileStorage_hpp__pyplusplus_wrapper
#define FileStorage_hpp__pyplusplus_wrapper

void register_FileStorage_class();

#endif//FileStorage_hpp__pyplusplus_wrapper
