// This file has been generated by Py++.

#ifndef CvSURFParams_hpp__pyplusplus_wrapper
#define CvSURFParams_hpp__pyplusplus_wrapper

void register_CvSURFParams_class();

#endif//CvSURFParams_hpp__pyplusplus_wrapper
