// This file has been generated by Py++.

#ifndef IntegralHistogram_hpp__pyplusplus_wrapper
#define IntegralHistogram_hpp__pyplusplus_wrapper

void register_IntegralHistogram_class();

#endif//IntegralHistogram_hpp__pyplusplus_wrapper
