// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvBlob.pypp.hpp"

namespace bp = boost::python;

void register_CvBlob_class(){

    bp::class_< CvBlob >( "CvBlob" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvBlob >() )    
        .def_readwrite( "ID", &CvBlob::ID )    
        .def_readwrite( "h", &CvBlob::h )    
        .def_readwrite( "w", &CvBlob::w )    
        .def_readwrite( "x", &CvBlob::x )    
        .def_readwrite( "y", &CvBlob::y );

}
