// This file has been generated by Py++.

#ifndef Ptr_BaseFilter_hpp__pyplusplus_wrapper
#define Ptr_BaseFilter_hpp__pyplusplus_wrapper

void register_Ptr_BaseFilter_class();

#endif//Ptr_BaseFilter_hpp__pyplusplus_wrapper
