// This file has been generated by Py++.

#ifndef CvGraphVtx2D_hpp__pyplusplus_wrapper
#define CvGraphVtx2D_hpp__pyplusplus_wrapper

void register_CvGraphVtx2D_class();

#endif//CvGraphVtx2D_hpp__pyplusplus_wrapper
