// This file has been generated by Py++.

#ifndef CvContourScanner_hpp__pyplusplus_wrapper
#define CvContourScanner_hpp__pyplusplus_wrapper

void register_CvContourScanner_class();

#endif//CvContourScanner_hpp__pyplusplus_wrapper
