// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvAffinePose.pypp.hpp"

namespace bp = boost::python;

void register_CvAffinePose_class(){

    bp::class_< cv::CvAffinePose >( "CvAffinePose" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< cv::CvAffinePose >() )    
        .def_readwrite( "lambda1", &cv::CvAffinePose::lambda1 )    
        .def_readwrite( "lambda2", &cv::CvAffinePose::lambda2 )    
        .def_readwrite( "phi", &cv::CvAffinePose::phi )    
        .def_readwrite( "theta", &cv::CvAffinePose::theta );

}
