// This file has been generated by Py++.

#ifndef CvPluginFuncInfo_hpp__pyplusplus_wrapper
#define CvPluginFuncInfo_hpp__pyplusplus_wrapper

void register_CvPluginFuncInfo_class();

#endif//CvPluginFuncInfo_hpp__pyplusplus_wrapper
