// This file has been generated by Py++.

#ifndef PatchGenerator_hpp__pyplusplus_wrapper
#define PatchGenerator_hpp__pyplusplus_wrapper

void register_PatchGenerator_class();

#endif//PatchGenerator_hpp__pyplusplus_wrapper
