// This file has been generated by Py++.

#ifndef OneWayDescriptor_hpp__pyplusplus_wrapper
#define OneWayDescriptor_hpp__pyplusplus_wrapper

void register_OneWayDescriptor_class();

#endif//OneWayDescriptor_hpp__pyplusplus_wrapper
