// This file has been generated by Py++.

#ifndef CvConnectedComp_hpp__pyplusplus_wrapper
#define CvConnectedComp_hpp__pyplusplus_wrapper

void register_CvConnectedComp_class();

#endif//CvConnectedComp_hpp__pyplusplus_wrapper
