// This file has been generated by Py++.

#ifndef CvEMParams_hpp__pyplusplus_wrapper
#define CvEMParams_hpp__pyplusplus_wrapper

void register_CvEMParams_class();

#endif//CvEMParams_hpp__pyplusplus_wrapper
