// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvSubdiv2DPoint.pypp.hpp"

namespace bp = boost::python;

void register_CvSubdiv2DPoint_class(){

    bp::class_< CvSubdiv2DPoint >( "CvSubdiv2DPoint" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvSubdiv2DPoint >() )    
        .def_readwrite( "first", &CvSubdiv2DPoint::first )    
        .def_readwrite( "flags", &CvSubdiv2DPoint::flags )    
        .def_readwrite( "id", &CvSubdiv2DPoint::id )    
        .def_readwrite( "pt", &CvSubdiv2DPoint::pt );

}
