// This file has been generated by Py++.

#ifndef Ptr_CvFileStorage_hpp__pyplusplus_wrapper
#define Ptr_CvFileStorage_hpp__pyplusplus_wrapper

void register_Ptr_CvFileStorage_class();

#endif//Ptr_CvFileStorage_hpp__pyplusplus_wrapper
