// This file has been generated by Py++.

#ifndef CvBlobSeq_hpp__pyplusplus_wrapper
#define CvBlobSeq_hpp__pyplusplus_wrapper

void register_CvBlobSeq_class();

#endif//CvBlobSeq_hpp__pyplusplus_wrapper
