// This file has been generated by Py++.

#ifndef Ptr_BaseRowFilter_hpp__pyplusplus_wrapper
#define Ptr_BaseRowFilter_hpp__pyplusplus_wrapper

void register_Ptr_BaseRowFilter_class();

#endif//Ptr_BaseRowFilter_hpp__pyplusplus_wrapper
