// This file has been generated by Py++.

#ifndef CvGraphVtx_hpp__pyplusplus_wrapper
#define CvGraphVtx_hpp__pyplusplus_wrapper

void register_CvGraphVtx_class();

#endif//CvGraphVtx_hpp__pyplusplus_wrapper
