// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvRect.pypp.hpp"

namespace bp = boost::python;

static boost::shared_ptr<CvRect> CvRect_init(int x, int y, int width, int height)
{
    CvRect *r = new CvRect(); *r = cvRect(x,y,width,height);
    return boost::shared_ptr<CvRect>(r);
}

void register_CvRect_class(){

    bp::class_< CvRect >( "CvRect" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvRect >() )    
        .def_readwrite( "height", &CvRect::height )    
        .def_readwrite( "width", &CvRect::width )    
        .def_readwrite( "x", &CvRect::x )    
        .def_readwrite( "y", &CvRect::y )    
        .def("__init__", bp::make_constructor(&CvRect_init, bp::default_call_policies(), ( bp::arg("x"), bp::arg("y"), bp::arg("width"), bp::arg("height") )));

}
