// This file has been generated by Py++.

#ifndef CvSeqWriter_hpp__pyplusplus_wrapper
#define CvSeqWriter_hpp__pyplusplus_wrapper

void register_CvSeqWriter_class();

#endif//CvSeqWriter_hpp__pyplusplus_wrapper
