// This file has been generated by Py++.

#ifndef CascadeClassifier_hpp__pyplusplus_wrapper
#define CascadeClassifier_hpp__pyplusplus_wrapper

void register_CascadeClassifier_class();

#endif//CascadeClassifier_hpp__pyplusplus_wrapper
