// This file has been generated by Py++.

#ifndef DifferentialImage_hpp__pyplusplus_wrapper
#define DifferentialImage_hpp__pyplusplus_wrapper

void register_DifferentialImage_class();

#endif//DifferentialImage_hpp__pyplusplus_wrapper
