// This file has been generated by Py++.

#ifndef CvForestERTree_hpp__pyplusplus_wrapper
#define CvForestERTree_hpp__pyplusplus_wrapper

void register_CvForestERTree_class();

#endif//CvForestERTree_hpp__pyplusplus_wrapper
