// This file has been generated by Py++.

#ifndef CvFileStorage_hpp__pyplusplus_wrapper
#define CvFileStorage_hpp__pyplusplus_wrapper

void register_CvFileStorage_class();

#endif//CvFileStorage_hpp__pyplusplus_wrapper
