// This file has been generated by Py++.

#ifndef CvConvexityDefect_hpp__pyplusplus_wrapper
#define CvConvexityDefect_hpp__pyplusplus_wrapper

void register_CvConvexityDefect_class();

#endif//CvConvexityDefect_hpp__pyplusplus_wrapper
