// This file has been generated by Py++.

#ifndef SearchParams_hpp__pyplusplus_wrapper
#define SearchParams_hpp__pyplusplus_wrapper

void register_SearchParams_class();

#endif//SearchParams_hpp__pyplusplus_wrapper
