// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "SparseMatIterator.pypp.hpp"

namespace bp = boost::python;

void register_SparseMatIterator_class(){

    { //::cv::SparseMatIterator
        typedef bp::class_< cv::SparseMatIterator, bp::bases< cv::SparseMatConstIterator > > SparseMatIterator_exposer_t;
        SparseMatIterator_exposer_t SparseMatIterator_exposer = SparseMatIterator_exposer_t( "SparseMatIterator" );
        bp::scope SparseMatIterator_scope( SparseMatIterator_exposer );
        SparseMatIterator_exposer.add_property( "this", pyplus_conv::make_addressof_inst_getter< cv::SparseMatIterator >() );
    }

}
