// This file has been generated by Py++.

#ifndef CvGenericHash_hpp__pyplusplus_wrapper
#define CvGenericHash_hpp__pyplusplus_wrapper

void register_CvGenericHash_class();

#endif//CvGenericHash_hpp__pyplusplus_wrapper
