// This file has been generated by Py++.

#ifndef CvMSERParams_hpp__pyplusplus_wrapper
#define CvMSERParams_hpp__pyplusplus_wrapper

void register_CvMSERParams_class();

#endif//CvMSERParams_hpp__pyplusplus_wrapper
