// This file has been generated by Py++.

#ifndef CvFeatureTree_hpp__pyplusplus_wrapper
#define CvFeatureTree_hpp__pyplusplus_wrapper

void register_CvFeatureTree_class();

#endif//CvFeatureTree_hpp__pyplusplus_wrapper
