// This file has been generated by Py++.

#ifndef CvCamShiftTracker_hpp__pyplusplus_wrapper
#define CvCamShiftTracker_hpp__pyplusplus_wrapper

void register_CvCamShiftTracker_class();

#endif//CvCamShiftTracker_hpp__pyplusplus_wrapper
