// This file has been generated by Py++.

#ifndef HOGDescriptor_hpp__pyplusplus_wrapper
#define HOGDescriptor_hpp__pyplusplus_wrapper

void register_HOGDescriptor_class();

#endif//HOGDescriptor_hpp__pyplusplus_wrapper
