// This file has been generated by Py++.

#ifndef Ptr_CvStereoBMState_hpp__pyplusplus_wrapper
#define Ptr_CvStereoBMState_hpp__pyplusplus_wrapper

void register_Ptr_CvStereoBMState_class();

#endif//Ptr_CvStereoBMState_hpp__pyplusplus_wrapper
