// This file has been generated by Py++.

#ifndef CvQuadEdge2D_hpp__pyplusplus_wrapper
#define CvQuadEdge2D_hpp__pyplusplus_wrapper

void register_CvQuadEdge2D_class();

#endif//CvQuadEdge2D_hpp__pyplusplus_wrapper
