// This file has been generated by Py++.

#ifndef SparseMatIterator_hpp__pyplusplus_wrapper
#define SparseMatIterator_hpp__pyplusplus_wrapper

void register_SparseMatIterator_class();

#endif//SparseMatIterator_hpp__pyplusplus_wrapper
