// This file has been generated by Py++.

#ifndef CvFileNode_hpp__pyplusplus_wrapper
#define CvFileNode_hpp__pyplusplus_wrapper

void register_CvFileNode_class();

#endif//CvFileNode_hpp__pyplusplus_wrapper
