// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvStarKeypoint.pypp.hpp"

namespace bp = boost::python;

void register_CvStarKeypoint_class(){

    bp::class_< CvStarKeypoint >( "CvStarKeypoint" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvStarKeypoint >() )    
        .def_readwrite( "pt", &CvStarKeypoint::pt )    
        .def_readwrite( "response", &CvStarKeypoint::response )    
        .def_readwrite( "size", &CvStarKeypoint::size );

}
