// This file has been generated by Py++.

#ifndef CvLSHOperations_hpp__pyplusplus_wrapper
#define CvLSHOperations_hpp__pyplusplus_wrapper

void register_CvLSHOperations_class();

#endif//CvLSHOperations_hpp__pyplusplus_wrapper
