// This file has been generated by Py++.

#ifndef AutotunedIndexParams_hpp__pyplusplus_wrapper
#define AutotunedIndexParams_hpp__pyplusplus_wrapper

void register_AutotunedIndexParams_class();

#endif//AutotunedIndexParams_hpp__pyplusplus_wrapper
