// This file has been generated by Py++.

#ifndef CvKNearest_hpp__pyplusplus_wrapper
#define CvKNearest_hpp__pyplusplus_wrapper

void register_CvKNearest_class();

#endif//CvKNearest_hpp__pyplusplus_wrapper
