// This file has been generated by Py++.

#ifndef CvStereoGCState_hpp__pyplusplus_wrapper
#define CvStereoGCState_hpp__pyplusplus_wrapper

void register_CvStereoGCState_class();

#endif//CvStereoGCState_hpp__pyplusplus_wrapper
