// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "Ptr_BaseColumnFilter.pypp.hpp"

namespace bp = boost::python;

cv::BaseColumnFilter const &pointee_BaseColumnFilter(cv::Ptr<cv::BaseColumnFilter> const &inst) { return *((cv::BaseColumnFilter const *)inst); }

void register_Ptr_BaseColumnFilter_class(){

    { //::cv::Ptr< cv::BaseColumnFilter >
        typedef bp::class_< cv::Ptr< cv::BaseColumnFilter > > Ptr_BaseColumnFilter_exposer_t;
        Ptr_BaseColumnFilter_exposer_t Ptr_BaseColumnFilter_exposer = Ptr_BaseColumnFilter_exposer_t( "Ptr_BaseColumnFilter" );
        bp::scope Ptr_BaseColumnFilter_scope( Ptr_BaseColumnFilter_exposer );
        Ptr_BaseColumnFilter_exposer.add_property( "this", pyplus_conv::make_addressof_inst_getter< cv::Ptr< cv::BaseColumnFilter > >() );
        { //::cv::Ptr< cv::BaseColumnFilter >::addref
        
            typedef cv::Ptr< cv::BaseColumnFilter > exported_class_t;
            typedef void ( exported_class_t::*addref_function_type )(  ) ;
            
            Ptr_BaseColumnFilter_exposer.def( 
                "addref"
                , addref_function_type( &::cv::Ptr< cv::BaseColumnFilter >::addref ) );
        
        }
        { //::cv::Ptr< cv::BaseColumnFilter >::delete_obj
        
            typedef cv::Ptr< cv::BaseColumnFilter > exported_class_t;
            typedef void ( exported_class_t::*delete_obj_function_type )(  ) ;
            
            Ptr_BaseColumnFilter_exposer.def( 
                "delete_obj"
                , delete_obj_function_type( &::cv::Ptr< cv::BaseColumnFilter >::delete_obj ) );
        
        }
        { //::cv::Ptr< cv::BaseColumnFilter >::empty
        
            typedef cv::Ptr< cv::BaseColumnFilter > exported_class_t;
            typedef bool ( exported_class_t::*empty_function_type )(  ) const;
            
            Ptr_BaseColumnFilter_exposer.def( 
                "empty"
                , empty_function_type( &::cv::Ptr< cv::BaseColumnFilter >::empty ) );
        
        }
        { //::cv::Ptr< cv::BaseColumnFilter >::release
        
            typedef cv::Ptr< cv::BaseColumnFilter > exported_class_t;
            typedef void ( exported_class_t::*release_function_type )(  ) ;
            
            Ptr_BaseColumnFilter_exposer.def( 
                "release"
                , release_function_type( &::cv::Ptr< cv::BaseColumnFilter >::release ) );
        
        }
        Ptr_BaseColumnFilter_exposer.add_property("pointee", bp::make_function(&pointee_BaseColumnFilter, bp::return_internal_reference<>()));
    }

}
