// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "boost/python/object.hpp"
#include "CvSetElem.pypp.hpp"

namespace bp = boost::python;

static ::CvSetElem * get_next_free( ::CvSetElem const & inst ) { return inst.next_free; }

void register_CvSetElem_class(){

    bp::class_< CvSetElem >( "CvSetElem" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvSetElem >() )    
        .def_readwrite( "flags", &CvSetElem::flags )    
        .add_property( "next_free", bp::make_function(&::get_next_free, bp::return_internal_reference<>()) );

}
