// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "SparseMatConstIterator.pypp.hpp"

namespace bp = boost::python;

void register_SparseMatConstIterator_class(){

    { //::cv::SparseMatConstIterator
        typedef bp::class_< cv::SparseMatConstIterator > SparseMatConstIterator_exposer_t;
        SparseMatConstIterator_exposer_t SparseMatConstIterator_exposer = SparseMatConstIterator_exposer_t( "SparseMatConstIterator" );
        bp::scope SparseMatConstIterator_scope( SparseMatConstIterator_exposer );
        SparseMatConstIterator_exposer.add_property( "this", pyplus_conv::make_addressof_inst_getter< cv::SparseMatConstIterator >() );
    }

}
