// This file has been generated by Py++.

#ifndef CvMemBlock_hpp__pyplusplus_wrapper
#define CvMemBlock_hpp__pyplusplus_wrapper

void register_CvMemBlock_class();

#endif//CvMemBlock_hpp__pyplusplus_wrapper
