// This file has been generated by Py++.

#ifndef CvGraphScanner_hpp__pyplusplus_wrapper
#define CvGraphScanner_hpp__pyplusplus_wrapper

void register_CvGraphScanner_class();

#endif//CvGraphScanner_hpp__pyplusplus_wrapper
