// This file has been generated by Py++.

#ifndef Ptr_FilterEngine_hpp__pyplusplus_wrapper
#define Ptr_FilterEngine_hpp__pyplusplus_wrapper

void register_Ptr_FilterEngine_class();

#endif//Ptr_FilterEngine_hpp__pyplusplus_wrapper
