// This file has been generated by Py++.

#ifndef CvHidHaarClassifierCascade_hpp__pyplusplus_wrapper
#define CvHidHaarClassifierCascade_hpp__pyplusplus_wrapper

void register_CvHidHaarClassifierCascade_class();

#endif//CvHidHaarClassifierCascade_hpp__pyplusplus_wrapper
