// This file has been generated by Py++.

#ifndef CvContour_hpp__pyplusplus_wrapper
#define CvContour_hpp__pyplusplus_wrapper

void register_CvContour_class();

#endif//CvContour_hpp__pyplusplus_wrapper
