// This file has been generated by Py++.

#ifndef VideoWriter_hpp__pyplusplus_wrapper
#define VideoWriter_hpp__pyplusplus_wrapper

void register_VideoWriter_class();

#endif//VideoWriter_hpp__pyplusplus_wrapper
