// This file has been generated by Py++.

#ifndef CvSubdiv2DPoint_hpp__pyplusplus_wrapper
#define CvSubdiv2DPoint_hpp__pyplusplus_wrapper

void register_CvSubdiv2DPoint_class();

#endif//CvSubdiv2DPoint_hpp__pyplusplus_wrapper
