// This file has been generated by Py++.

#ifndef CvRTParams_hpp__pyplusplus_wrapper
#define CvRTParams_hpp__pyplusplus_wrapper

void register_CvRTParams_class();

#endif//CvRTParams_hpp__pyplusplus_wrapper
