// This file has been generated by Py++.

#ifndef pyopencvext_global_variables_hpp__pyplusplus_wrapper
#define pyopencvext_global_variables_hpp__pyplusplus_wrapper

void register_global_variables();

#endif//pyopencvext_global_variables_hpp__pyplusplus_wrapper
