// This file has been generated by Py++.

#ifndef CvChainPtReader_hpp__pyplusplus_wrapper
#define CvChainPtReader_hpp__pyplusplus_wrapper

void register_CvChainPtReader_class();

#endif//CvChainPtReader_hpp__pyplusplus_wrapper
