// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "boost/python/object.hpp"
#include "CvMemStoragePos.pypp.hpp"

namespace bp = boost::python;

static ::CvMemBlock * get_top( ::CvMemStoragePos const & inst ) { return inst.top; }

void register_CvMemStoragePos_class(){

    bp::class_< CvMemStoragePos >( "CvMemStoragePos" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvMemStoragePos >() )    
        .def_readwrite( "free_space", &CvMemStoragePos::free_space )    
        .add_property( "top", bp::make_function(&::get_top, bp::return_internal_reference<>()) );

}
