// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "boost/python/object.hpp"
#include "CvType.pypp.hpp"

namespace bp = boost::python;

static ::CvTypeInfo * get_info( ::CvType const & inst ) { return inst.info; }

static ::CvTypeInfo * get_first( ::CvType const & inst ) { return inst.first; }

static ::CvTypeInfo * get_last( ::CvType const & inst ) { return inst.last; }

void register_CvType_class(){

    bp::class_< CvType >( "CvType", bp::no_init )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvType >() )    
        .add_property( "info", bp::make_function(&::get_info, bp::return_internal_reference<>()) )    
        .add_property( "first", bp::make_function(&::get_first, bp::return_internal_reference<>()) )    
        .add_property( "last", bp::make_function(&::get_last, bp::return_internal_reference<>()) );

}
