// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "boost/python/object.hpp"
#include "CvConvexityDefect.pypp.hpp"

namespace bp = boost::python;

static ::CvPoint * get_start( ::CvConvexityDefect const & inst ) { return inst.start; }

static ::CvPoint * get_end( ::CvConvexityDefect const & inst ) { return inst.end; }

static ::CvPoint * get_depth_point( ::CvConvexityDefect const & inst ) { return inst.depth_point; }

void register_CvConvexityDefect_class(){

    bp::class_< CvConvexityDefect >( "CvConvexityDefect" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvConvexityDefect >() )    
        .def_readwrite( "depth", &CvConvexityDefect::depth )    
        .add_property( "start", bp::make_function(&::get_start, bp::return_internal_reference<>()) )    
        .add_property( "end", bp::make_function(&::get_end, bp::return_internal_reference<>()) )    
        .add_property( "depth_point", bp::make_function(&::get_depth_point, bp::return_internal_reference<>()) );

}
