// This file has been generated by Py++.

#ifndef FilterEngine_hpp__pyplusplus_wrapper
#define FilterEngine_hpp__pyplusplus_wrapper

void register_FilterEngine_class();

#endif//FilterEngine_hpp__pyplusplus_wrapper
