// sdopencv - SharkDolphin's Extensions for OpenCV
//
// Copyright 2010 Minh-Tri Pham.
// Third party copyrights are property of their respective owners.
//
// This file is part of sdopencv.
//
// sdopencv is licensed under the New BSD License.

#ifndef __SDOPENCV_HPP
#define __SDOPENCV_HPP

#include "dtype.hpp"
#include "diffchar_2d.hpp"
#include "integral_2d.hpp"
#include "int_hist_2d.hpp"

#endif

