// This file has been generated by Py++.

#ifndef CvAffinePose_hpp__pyplusplus_wrapper
#define CvAffinePose_hpp__pyplusplus_wrapper

void register_CvAffinePose_class();

#endif//CvAffinePose_hpp__pyplusplus_wrapper
