// This file has been generated by Py++.

#ifndef CvFuzzyRule_hpp__pyplusplus_wrapper
#define CvFuzzyRule_hpp__pyplusplus_wrapper

void register_CvFuzzyRule_class();

#endif//CvFuzzyRule_hpp__pyplusplus_wrapper
