// This file has been generated by Py++.

#ifndef CvFuzzyController_hpp__pyplusplus_wrapper
#define CvFuzzyController_hpp__pyplusplus_wrapper

void register_CvFuzzyController_class();

#endif//CvFuzzyController_hpp__pyplusplus_wrapper
