// This file has been generated by Py++.

#ifndef pyopencvext_free_functions_hpp__pyplusplus_wrapper
#define pyopencvext_free_functions_hpp__pyplusplus_wrapper

void register_free_functions();

#endif//pyopencvext_free_functions_hpp__pyplusplus_wrapper
