// This file has been generated by Py++.

#ifndef TermCriteria_hpp__pyplusplus_wrapper
#define TermCriteria_hpp__pyplusplus_wrapper

void register_TermCriteria_class();

#endif//TermCriteria_hpp__pyplusplus_wrapper
