// This file has been generated by Py++.

#ifndef CvTreeNodeIterator_hpp__pyplusplus_wrapper
#define CvTreeNodeIterator_hpp__pyplusplus_wrapper

void register_CvTreeNodeIterator_class();

#endif//CvTreeNodeIterator_hpp__pyplusplus_wrapper
