// This file has been generated by Py++.

#ifndef TickMeter_hpp__pyplusplus_wrapper
#define TickMeter_hpp__pyplusplus_wrapper

void register_TickMeter_class();

#endif//TickMeter_hpp__pyplusplus_wrapper
