// This file has been generated by Py++.

#ifndef SparseMatConstIterator_hpp__pyplusplus_wrapper
#define SparseMatConstIterator_hpp__pyplusplus_wrapper

void register_SparseMatConstIterator_class();

#endif//SparseMatConstIterator_hpp__pyplusplus_wrapper
