// This file has been generated by Py++.

#ifndef BackgroundSubtractor_hpp__pyplusplus_wrapper
#define BackgroundSubtractor_hpp__pyplusplus_wrapper

void register_BackgroundSubtractor_class();

#endif//BackgroundSubtractor_hpp__pyplusplus_wrapper
