// This file has been generated by Py++.

#ifndef pyopencvext_enumerations_hpp__pyplusplus_wrapper
#define pyopencvext_enumerations_hpp__pyplusplus_wrapper

void register_enumerations();

#endif//pyopencvext_enumerations_hpp__pyplusplus_wrapper
