// This file has been generated by Py++.

#ifndef __dummy_struct_hpp__pyplusplus_wrapper
#define __dummy_struct_hpp__pyplusplus_wrapper

void register___dummy_struct_class();

#endif//__dummy_struct_hpp__pyplusplus_wrapper
