// This file has been generated by Py++.

#ifndef LevMarqSparse_hpp__pyplusplus_wrapper
#define LevMarqSparse_hpp__pyplusplus_wrapper

void register_LevMarqSparse_class();

#endif//LevMarqSparse_hpp__pyplusplus_wrapper
