// This file has been generated by Py++.

#ifndef CvHaarStageClassifier_hpp__pyplusplus_wrapper
#define CvHaarStageClassifier_hpp__pyplusplus_wrapper

void register_CvHaarStageClassifier_class();

#endif//CvHaarStageClassifier_hpp__pyplusplus_wrapper
