// This file has been generated by Py++.

#ifndef CvTypeInfo_hpp__pyplusplus_wrapper
#define CvTypeInfo_hpp__pyplusplus_wrapper

void register_CvTypeInfo_class();

#endif//CvTypeInfo_hpp__pyplusplus_wrapper
