// This file has been generated by Py++.

#ifndef CvForestTree_hpp__pyplusplus_wrapper
#define CvForestTree_hpp__pyplusplus_wrapper

void register_CvForestTree_class();

#endif//CvForestTree_hpp__pyplusplus_wrapper
