// This file has been generated by Py++.

#ifndef CvBoostTree_hpp__pyplusplus_wrapper
#define CvBoostTree_hpp__pyplusplus_wrapper

void register_CvBoostTree_class();

#endif//CvBoostTree_hpp__pyplusplus_wrapper
