// This file has been generated by Py++.

#ifndef IndexParams_hpp__pyplusplus_wrapper
#define IndexParams_hpp__pyplusplus_wrapper

void register_IndexParams_class();

#endif//IndexParams_hpp__pyplusplus_wrapper
