// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "lsh_hash.pypp.hpp"

namespace bp = boost::python;

void register_lsh_hash_class(){

    bp::class_< lsh_hash >( "lsh_hash" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< lsh_hash >() )    
        .def_readwrite( "h1", &lsh_hash::h1 )    
        .def_readwrite( "h2", &lsh_hash::h2 );

}
