// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvBoostParams.pypp.hpp"

namespace bp = boost::python;

void register_CvBoostParams_class(){

    bp::class_< CvBoostParams, bp::bases< CvDTreeParams > >( "CvBoostParams", bp::init< >() )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvBoostParams >() )    
        .def( bp::init< int, int, double, int, bool, float const * >(( bp::arg("boost_type"), bp::arg("weak_count"), bp::arg("weight_trim_rate"), bp::arg("max_depth"), bp::arg("use_surrogates"), bp::arg("priors") )) )    
        .def_readwrite( "boost_type", &CvBoostParams::boost_type )    
        .def_readwrite( "split_criteria", &CvBoostParams::split_criteria )    
        .def_readwrite( "weak_count", &CvBoostParams::weak_count )    
        .def_readwrite( "weight_trim_rate", &CvBoostParams::weight_trim_rate );

}
