// This file has been generated by Py++.

#ifndef CvPOSITObject_hpp__pyplusplus_wrapper
#define CvPOSITObject_hpp__pyplusplus_wrapper

void register_CvPOSITObject_class();

#endif//CvPOSITObject_hpp__pyplusplus_wrapper
