// This file has been generated by Py++.

#ifndef LinearIndexParams_hpp__pyplusplus_wrapper
#define LinearIndexParams_hpp__pyplusplus_wrapper

void register_LinearIndexParams_class();

#endif//LinearIndexParams_hpp__pyplusplus_wrapper
