// This file has been generated by Py++.

#ifndef KDTreeIndexParams_hpp__pyplusplus_wrapper
#define KDTreeIndexParams_hpp__pyplusplus_wrapper

void register_KDTreeIndexParams_class();

#endif//KDTreeIndexParams_hpp__pyplusplus_wrapper
