// This file has been generated by Py++.

#ifndef CvFuzzyFunction_hpp__pyplusplus_wrapper
#define CvFuzzyFunction_hpp__pyplusplus_wrapper

void register_CvFuzzyFunction_class();

#endif//CvFuzzyFunction_hpp__pyplusplus_wrapper
