// This file has been generated by Py++.

#ifndef Ptr_BaseColumnFilter_hpp__pyplusplus_wrapper
#define Ptr_BaseColumnFilter_hpp__pyplusplus_wrapper

void register_Ptr_BaseColumnFilter_class();

#endif//Ptr_BaseColumnFilter_hpp__pyplusplus_wrapper
