// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "boost/python/object.hpp"
#include "CvGraphVtx2D.pypp.hpp"

namespace bp = boost::python;

static ::CvGraphEdge * get_first( ::CvGraphVtx2D const & inst ) { return inst.first; }

static ::CvPoint2D32f * get_ptr( ::CvGraphVtx2D const & inst ) { return inst.ptr; }

void register_CvGraphVtx2D_class(){

    bp::class_< CvGraphVtx2D >( "CvGraphVtx2D" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvGraphVtx2D >() )    
        .def_readwrite( "flags", &CvGraphVtx2D::flags )    
        .add_property( "first", bp::make_function(&::get_first, bp::return_internal_reference<>()) )    
        .add_property( "ptr", bp::make_function(&::get_ptr, bp::return_internal_reference<>()) );

}
