// This file has been generated by Py++.

#ifndef CvNArrayIterator_hpp__pyplusplus_wrapper
#define CvNArrayIterator_hpp__pyplusplus_wrapper

void register_CvNArrayIterator_class();

#endif//CvNArrayIterator_hpp__pyplusplus_wrapper
