// This file has been generated by Py++.

#ifndef CvContourTree_hpp__pyplusplus_wrapper
#define CvContourTree_hpp__pyplusplus_wrapper

void register_CvContourTree_class();

#endif//CvContourTree_hpp__pyplusplus_wrapper
