// This file has been generated by Py++.

#ifndef VideoCapture_hpp__pyplusplus_wrapper
#define VideoCapture_hpp__pyplusplus_wrapper

void register_VideoCapture_class();

#endif//VideoCapture_hpp__pyplusplus_wrapper
