// This file has been generated by Py++.

#ifndef KalmanFilter_hpp__pyplusplus_wrapper
#define KalmanFilter_hpp__pyplusplus_wrapper

void register_KalmanFilter_class();

#endif//KalmanFilter_hpp__pyplusplus_wrapper
