// This file has been generated by Py++.

#ifndef CvDetectedBlob_hpp__pyplusplus_wrapper
#define CvDetectedBlob_hpp__pyplusplus_wrapper

void register_CvDetectedBlob_class();

#endif//CvDetectedBlob_hpp__pyplusplus_wrapper
