// This file has been generated by Py++.

#ifndef CvStarKeypoint_hpp__pyplusplus_wrapper
#define CvStarKeypoint_hpp__pyplusplus_wrapper

void register_CvStarKeypoint_class();

#endif//CvStarKeypoint_hpp__pyplusplus_wrapper
