// This file has been generated by Py++.

#ifndef FeatureEvaluator_hpp__pyplusplus_wrapper
#define FeatureEvaluator_hpp__pyplusplus_wrapper

void register_FeatureEvaluator_class();

#endif//FeatureEvaluator_hpp__pyplusplus_wrapper
