// This file has been generated by Py++.

#ifndef CvBlobTrack_hpp__pyplusplus_wrapper
#define CvBlobTrack_hpp__pyplusplus_wrapper

void register_CvBlobTrack_class();

#endif//CvBlobTrack_hpp__pyplusplus_wrapper
