// This file has been generated by Py++.

#ifndef SpinImageModel_hpp__pyplusplus_wrapper
#define SpinImageModel_hpp__pyplusplus_wrapper

void register_SpinImageModel_class();

#endif//SpinImageModel_hpp__pyplusplus_wrapper
