// This file has been generated by Py++.

#ifndef CvLevMarq_hpp__pyplusplus_wrapper
#define CvLevMarq_hpp__pyplusplus_wrapper

void register_CvLevMarq_class();

#endif//CvLevMarq_hpp__pyplusplus_wrapper
