// This file has been generated by Py++.

#ifndef IntegralImage_hpp__pyplusplus_wrapper
#define IntegralImage_hpp__pyplusplus_wrapper

void register_IntegralImage_class();

#endif//IntegralImage_hpp__pyplusplus_wrapper
