// This file has been generated by Py++.

#ifndef CvSubdiv2D_hpp__pyplusplus_wrapper
#define CvSubdiv2D_hpp__pyplusplus_wrapper

void register_CvSubdiv2D_class();

#endif//CvSubdiv2D_hpp__pyplusplus_wrapper
