// This file has been generated by Py++.

#ifndef CvSeqBlock_hpp__pyplusplus_wrapper
#define CvSeqBlock_hpp__pyplusplus_wrapper

void register_CvSeqBlock_class();

#endif//CvSeqBlock_hpp__pyplusplus_wrapper
