// This file has been generated by Py++.

#ifndef IndexFactory_hpp__pyplusplus_wrapper
#define IndexFactory_hpp__pyplusplus_wrapper

void register_IndexFactory_class();

#endif//IndexFactory_hpp__pyplusplus_wrapper
