// This file has been generated by Py++.

#ifndef CvVSModule_hpp__pyplusplus_wrapper
#define CvVSModule_hpp__pyplusplus_wrapper

void register_CvVSModule_class();

#endif//CvVSModule_hpp__pyplusplus_wrapper
