// This file has been generated by Py++.

#ifndef CvStatModel_hpp__pyplusplus_wrapper
#define CvStatModel_hpp__pyplusplus_wrapper

void register_CvStatModel_class();

#endif//CvStatModel_hpp__pyplusplus_wrapper
