// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "boost/python/object.hpp"
#include "CvBlobTrack.pypp.hpp"

namespace bp = boost::python;

static ::CvBlobSeq * get_pBlobSeq( ::CvBlobTrack const & inst ) { return inst.pBlobSeq; }

void register_CvBlobTrack_class(){

    bp::class_< CvBlobTrack >( "CvBlobTrack" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvBlobTrack >() )    
        .def_readwrite( "StartFrame", &CvBlobTrack::StartFrame )    
        .def_readwrite( "TrackID", &CvBlobTrack::TrackID )    
        .add_property( "pBlobSeq", bp::make_function(&::get_pBlobSeq, bp::return_internal_reference<>()) );

}
