// This file has been generated by Py++.

#ifndef SelfSimDescriptor_hpp__pyplusplus_wrapper
#define SelfSimDescriptor_hpp__pyplusplus_wrapper

void register_SelfSimDescriptor_class();

#endif//SelfSimDescriptor_hpp__pyplusplus_wrapper
