// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvStarDetectorParams.pypp.hpp"

namespace bp = boost::python;

void register_CvStarDetectorParams_class(){

    bp::class_< CvStarDetectorParams >( "CvStarDetectorParams" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvStarDetectorParams >() )    
        .def_readwrite( "lineThresholdBinarized", &CvStarDetectorParams::lineThresholdBinarized )    
        .def_readwrite( "lineThresholdProjected", &CvStarDetectorParams::lineThresholdProjected )    
        .def_readwrite( "maxSize", &CvStarDetectorParams::maxSize )    
        .def_readwrite( "responseThreshold", &CvStarDetectorParams::responseThreshold )    
        .def_readwrite( "suppressNonmaxSize", &CvStarDetectorParams::suppressNonmaxSize );

}
