// This file has been generated by Py++.

#ifndef LineIterator_hpp__pyplusplus_wrapper
#define LineIterator_hpp__pyplusplus_wrapper

void register_LineIterator_class();

#endif//LineIterator_hpp__pyplusplus_wrapper
