// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvSize.pypp.hpp"

namespace bp = boost::python;

static boost::shared_ptr<CvSize> CvSize_init(int width, int height)
{
    CvSize *r = new CvSize(); *r = cvSize(width,height);
    return boost::shared_ptr<CvSize>(r);
}

void register_CvSize_class(){

    bp::class_< CvSize >( "CvSize" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvSize >() )    
        .def_readwrite( "height", &CvSize::height )    
        .def_readwrite( "width", &CvSize::width )    
        .def("__init__", bp::make_constructor(&CvSize_init, bp::default_call_policies(), ( bp::arg("width"), bp::arg("height") )));

}
