// This file has been generated by Py++.

#ifndef OneWayDescriptorBase_hpp__pyplusplus_wrapper
#define OneWayDescriptorBase_hpp__pyplusplus_wrapper

void register_OneWayDescriptorBase_class();

#endif//OneWayDescriptorBase_hpp__pyplusplus_wrapper
