// This file has been generated by Py++.

#ifndef KMeansIndexParams_hpp__pyplusplus_wrapper
#define KMeansIndexParams_hpp__pyplusplus_wrapper

void register_KMeansIndexParams_class();

#endif//KMeansIndexParams_hpp__pyplusplus_wrapper
