// This file has been generated by Py++.

#ifndef CvStringHashNode_hpp__pyplusplus_wrapper
#define CvStringHashNode_hpp__pyplusplus_wrapper

void register_CvStringHashNode_class();

#endif//CvStringHashNode_hpp__pyplusplus_wrapper
