// This file has been generated by Py++.

#ifndef CvSetElem_hpp__pyplusplus_wrapper
#define CvSetElem_hpp__pyplusplus_wrapper

void register_CvSetElem_class();

#endif//CvSetElem_hpp__pyplusplus_wrapper
