// This file has been generated by Py++.

#ifndef SavedIndexParams_hpp__pyplusplus_wrapper
#define SavedIndexParams_hpp__pyplusplus_wrapper

void register_SavedIndexParams_class();

#endif//SavedIndexParams_hpp__pyplusplus_wrapper
