// This file has been generated by Py++.

#ifndef LDetector_hpp__pyplusplus_wrapper
#define LDetector_hpp__pyplusplus_wrapper

void register_LDetector_class();

#endif//LDetector_hpp__pyplusplus_wrapper
