// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "SearchParams.pypp.hpp"

namespace bp = boost::python;

void register_SearchParams_class(){

    { //::cv::flann::SearchParams
        typedef bp::class_< cv::flann::SearchParams > SearchParams_exposer_t;
        SearchParams_exposer_t SearchParams_exposer = SearchParams_exposer_t( "SearchParams", bp::init< bp::optional< int > >(( bp::arg("checks_")=(int)(32) )) );
        bp::scope SearchParams_scope( SearchParams_exposer );
        SearchParams_exposer.add_property( "this", pyplus_conv::make_addressof_inst_getter< cv::flann::SearchParams >() );
        bp::implicitly_convertible< int, cv::flann::SearchParams >();
        SearchParams_exposer.def_readwrite( "checks", &cv::flann::SearchParams::checks );
    }

}
