// This file has been generated by Py++.

#ifndef CvMemStoragePos_hpp__pyplusplus_wrapper
#define CvMemStoragePos_hpp__pyplusplus_wrapper

void register_CvMemStoragePos_class();

#endif//CvMemStoragePos_hpp__pyplusplus_wrapper
