// This file has been generated by Py++.

#ifndef CvANN_MLP_hpp__pyplusplus_wrapper
#define CvANN_MLP_hpp__pyplusplus_wrapper

void register_CvANN_MLP_class();

#endif//CvANN_MLP_hpp__pyplusplus_wrapper
