// This file has been generated by Py++.

#ifndef CvDTreeSplit_hpp__pyplusplus_wrapper
#define CvDTreeSplit_hpp__pyplusplus_wrapper

void register_CvDTreeSplit_class();

#endif//CvDTreeSplit_hpp__pyplusplus_wrapper
