// This file has been generated by Py++.

#ifndef CvERTrees_hpp__pyplusplus_wrapper
#define CvERTrees_hpp__pyplusplus_wrapper

void register_CvERTrees_class();

#endif//CvERTrees_hpp__pyplusplus_wrapper
