// This file has been generated by Py++.

#ifndef CvDTreeTrainData_hpp__pyplusplus_wrapper
#define CvDTreeTrainData_hpp__pyplusplus_wrapper

void register_CvDTreeTrainData_class();

#endif//CvDTreeTrainData_hpp__pyplusplus_wrapper
