// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvStereoGCState.pypp.hpp"

namespace bp = boost::python;

void register_CvStereoGCState_class(){

    bp::class_< CvStereoGCState >( "CvStereoGCState" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvStereoGCState >() )    
        .def_readwrite( "Ithreshold", &CvStereoGCState::Ithreshold )    
        .def_readwrite( "K", &CvStereoGCState::K )    
        .def_readwrite( "interactionRadius", &CvStereoGCState::interactionRadius )    
        .def_readwrite( "lambda", &CvStereoGCState::lambda )    
        .def_readwrite( "lambda1", &CvStereoGCState::lambda1 )    
        .def_readwrite( "lambda2", &CvStereoGCState::lambda2 )    
        .def_readwrite( "maxIters", &CvStereoGCState::maxIters )    
        .def_readwrite( "minDisparity", &CvStereoGCState::minDisparity )    
        .def_readwrite( "numberOfDisparities", &CvStereoGCState::numberOfDisparities )    
        .def_readwrite( "occlusionCost", &CvStereoGCState::occlusionCost );

}
