// This file has been generated by Py++.

#ifndef flann_Index_hpp__pyplusplus_wrapper
#define flann_Index_hpp__pyplusplus_wrapper

void register_flann_Index_class();

#endif//flann_Index_hpp__pyplusplus_wrapper
