// This file has been generated by Py++.

#ifndef StarDetector_hpp__pyplusplus_wrapper
#define StarDetector_hpp__pyplusplus_wrapper

void register_StarDetector_class();

#endif//StarDetector_hpp__pyplusplus_wrapper
