// This file has been generated by Py++.

#ifndef SparseMat_hpp__pyplusplus_wrapper
#define SparseMat_hpp__pyplusplus_wrapper

void register_SparseMat_class();

#endif//SparseMat_hpp__pyplusplus_wrapper
