// This file has been generated by Py++.

#ifndef CvSVMParams_hpp__pyplusplus_wrapper
#define CvSVMParams_hpp__pyplusplus_wrapper

void register_CvSVMParams_class();

#endif//CvSVMParams_hpp__pyplusplus_wrapper
