// This file has been generated by Py++.

#ifndef PlanarObjectDetector_hpp__pyplusplus_wrapper
#define PlanarObjectDetector_hpp__pyplusplus_wrapper

void register_PlanarObjectDetector_class();

#endif//PlanarObjectDetector_hpp__pyplusplus_wrapper
