// This file has been generated by Py++.

#ifndef CvHaarFeature_hpp__pyplusplus_wrapper
#define CvHaarFeature_hpp__pyplusplus_wrapper

void register_CvHaarFeature_class();

#endif//CvHaarFeature_hpp__pyplusplus_wrapper
