// This file has been generated by Py++.

#ifndef CvConDensation_hpp__pyplusplus_wrapper
#define CvConDensation_hpp__pyplusplus_wrapper

void register_CvConDensation_class();

#endif//CvConDensation_hpp__pyplusplus_wrapper
