// This file has been generated by Py++.

#ifndef CompositeIndexParams_hpp__pyplusplus_wrapper
#define CompositeIndexParams_hpp__pyplusplus_wrapper

void register_CompositeIndexParams_class();

#endif//CompositeIndexParams_hpp__pyplusplus_wrapper
