// This file has been generated by Py++.

#ifndef NAryMatNDIterator_hpp__pyplusplus_wrapper
#define NAryMatNDIterator_hpp__pyplusplus_wrapper

void register_NAryMatNDIterator_class();

#endif//NAryMatNDIterator_hpp__pyplusplus_wrapper
