// This file has been generated by Py++.

#ifndef CvNormalBayesClassifier_hpp__pyplusplus_wrapper
#define CvNormalBayesClassifier_hpp__pyplusplus_wrapper

void register_CvNormalBayesClassifier_class();

#endif//CvNormalBayesClassifier_hpp__pyplusplus_wrapper
