// This file has been generated by Py++.

#ifndef CvFuzzyCurve_hpp__pyplusplus_wrapper
#define CvFuzzyCurve_hpp__pyplusplus_wrapper

void register_CvFuzzyCurve_class();

#endif//CvFuzzyCurve_hpp__pyplusplus_wrapper
