// This file has been generated by Py++.

#ifndef CvBlobTrackSeq_hpp__pyplusplus_wrapper
#define CvBlobTrackSeq_hpp__pyplusplus_wrapper

void register_CvBlobTrackSeq_class();

#endif//CvBlobTrackSeq_hpp__pyplusplus_wrapper
