// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvHidHaarClassifierCascade.pypp.hpp"

namespace bp = boost::python;

void register_CvHidHaarClassifierCascade_class(){

    bp::class_< CvHidHaarClassifierCascade >( "CvHidHaarClassifierCascade" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvHidHaarClassifierCascade >() );

}
