// This file has been generated by Py++.

#ifndef CvParamGrid_hpp__pyplusplus_wrapper
#define CvParamGrid_hpp__pyplusplus_wrapper

void register_CvParamGrid_class();

#endif//CvParamGrid_hpp__pyplusplus_wrapper
