// This file has been generated by Py++.

#ifndef CvGraphEdge_hpp__pyplusplus_wrapper
#define CvGraphEdge_hpp__pyplusplus_wrapper

void register_CvGraphEdge_class();

#endif//CvGraphEdge_hpp__pyplusplus_wrapper
