// This file has been generated by Py++.

#ifndef CvAdaptiveSkinDetector_hpp__pyplusplus_wrapper
#define CvAdaptiveSkinDetector_hpp__pyplusplus_wrapper

void register_CvAdaptiveSkinDetector_class();

#endif//CvAdaptiveSkinDetector_hpp__pyplusplus_wrapper
