// This file has been generated by Py++.

#ifndef CvAttrList_hpp__pyplusplus_wrapper
#define CvAttrList_hpp__pyplusplus_wrapper

void register_CvAttrList_class();

#endif//CvAttrList_hpp__pyplusplus_wrapper
