// This file has been generated by Py++.

#ifndef StereoSGBM_hpp__pyplusplus_wrapper
#define StereoSGBM_hpp__pyplusplus_wrapper

void register_StereoSGBM_class();

#endif//StereoSGBM_hpp__pyplusplus_wrapper
