// This file has been generated by Py++.

#ifndef CvBoostParams_hpp__pyplusplus_wrapper
#define CvBoostParams_hpp__pyplusplus_wrapper

void register_CvBoostParams_class();

#endif//CvBoostParams_hpp__pyplusplus_wrapper
