// This file has been generated by Py++.

#ifndef Ptr_FeatureEvaluator_hpp__pyplusplus_wrapper
#define Ptr_FeatureEvaluator_hpp__pyplusplus_wrapper

void register_Ptr_FeatureEvaluator_class();

#endif//Ptr_FeatureEvaluator_hpp__pyplusplus_wrapper
