// This file has been generated by Py++.

#ifndef CvAvgComp_hpp__pyplusplus_wrapper
#define CvAvgComp_hpp__pyplusplus_wrapper

void register_CvAvgComp_class();

#endif//CvAvgComp_hpp__pyplusplus_wrapper
