// This file has been generated by Py++.

#ifndef CvStarDetectorParams_hpp__pyplusplus_wrapper
#define CvStarDetectorParams_hpp__pyplusplus_wrapper

void register_CvStarDetectorParams_class();

#endif//CvStarDetectorParams_hpp__pyplusplus_wrapper
