// This file has been generated by Py++.

#ifndef CvFuzzyMeanShiftTracker_hpp__pyplusplus_wrapper
#define CvFuzzyMeanShiftTracker_hpp__pyplusplus_wrapper

void register_CvFuzzyMeanShiftTracker_class();

#endif//CvFuzzyMeanShiftTracker_hpp__pyplusplus_wrapper
