// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "boost/python/object.hpp"
#include "CvGraphVtx.pypp.hpp"

namespace bp = boost::python;

static ::CvGraphEdge * get_first( ::CvGraphVtx const & inst ) { return inst.first; }

void register_CvGraphVtx_class(){

    bp::class_< CvGraphVtx >( "CvGraphVtx" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvGraphVtx >() )    
        .def_readwrite( "flags", &CvGraphVtx::flags )    
        .add_property( "first", bp::make_function(&::get_first, bp::return_internal_reference<>()) );

}
