// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "CvHaarFeature.pypp.hpp"

namespace bp = boost::python;

static cv::Rect *get_rect(CvHaarFeature const &inst, int i)
{
    return (cv::Rect *)&inst.rect[i].r;
}

static float get_rect_weight(CvHaarFeature const &inst, int i)
{
    return inst.rect[i].weight;
}

static void set_rect_weight(CvHaarFeature &inst, int i, float _weight)
{
    inst.rect[i].weight = _weight;
}

void register_CvHaarFeature_class(){

    bp::class_< CvHaarFeature >( "CvHaarFeature" )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvHaarFeature >() )    
        .add_property( "this", pyplus_conv::make_addressof_inst_getter< CvHaarFeature >() )    
        .def_readwrite( "tilted", &CvHaarFeature::tilted )    
        .def("get_rect", &::get_rect, bp::return_internal_reference<>())    
        .def("get_rect_weight", &::get_rect_weight)    
        .def("set_rect_weight", &::set_rect_weight);

}
