// This file has been generated by Py++.

#ifndef CvSURFPoint_hpp__pyplusplus_wrapper
#define CvSURFPoint_hpp__pyplusplus_wrapper

void register_CvSURFPoint_class();

#endif//CvSURFPoint_hpp__pyplusplus_wrapper
