// This file has been generated by Py++.

#ifndef CvHaarClassifierCascade_hpp__pyplusplus_wrapper
#define CvHaarClassifierCascade_hpp__pyplusplus_wrapper

void register_CvHaarClassifierCascade_class();

#endif//CvHaarClassifierCascade_hpp__pyplusplus_wrapper
