// This file has been generated by Py++.

#ifndef Ptr_CvHaarClassifierCascade_hpp__pyplusplus_wrapper
#define Ptr_CvHaarClassifierCascade_hpp__pyplusplus_wrapper

void register_Ptr_CvHaarClassifierCascade_class();

#endif//Ptr_CvHaarClassifierCascade_hpp__pyplusplus_wrapper
