// This file has been generated by Py++.

#ifndef CvModuleInfo_hpp__pyplusplus_wrapper
#define CvModuleInfo_hpp__pyplusplus_wrapper

void register_CvModuleInfo_class();

#endif//CvModuleInfo_hpp__pyplusplus_wrapper
