// This file has been generated by Py++.

#ifndef CvHaarClassifier_hpp__pyplusplus_wrapper
#define CvHaarClassifier_hpp__pyplusplus_wrapper

void register_CvHaarClassifier_class();

#endif//CvHaarClassifier_hpp__pyplusplus_wrapper
