// This file has been generated by Py++.

#ifndef CvSeqReader_hpp__pyplusplus_wrapper
#define CvSeqReader_hpp__pyplusplus_wrapper

void register_CvSeqReader_class();

#endif//CvSeqReader_hpp__pyplusplus_wrapper
