// This file has been generated by Py++.

#ifndef CvObjectDetector_hpp__pyplusplus_wrapper
#define CvObjectDetector_hpp__pyplusplus_wrapper

void register_CvObjectDetector_class();

#endif//CvObjectDetector_hpp__pyplusplus_wrapper
