// This file has been generated by Py++.

#ifndef DefaultRngAuto_hpp__pyplusplus_wrapper
#define DefaultRngAuto_hpp__pyplusplus_wrapper

void register_DefaultRngAuto_class();

#endif//DefaultRngAuto_hpp__pyplusplus_wrapper
