// This file has been generated by Py++.

#ifndef CvFuzzyPoint_hpp__pyplusplus_wrapper
#define CvFuzzyPoint_hpp__pyplusplus_wrapper

void register_CvFuzzyPoint_class();

#endif//CvFuzzyPoint_hpp__pyplusplus_wrapper
