// This file has been generated by Py++.

#ifndef CvDTreeParams_hpp__pyplusplus_wrapper
#define CvDTreeParams_hpp__pyplusplus_wrapper

void register_CvDTreeParams_class();

#endif//CvDTreeParams_hpp__pyplusplus_wrapper
