// This file has been generated by Py++.

#ifndef CvDefParam_hpp__pyplusplus_wrapper
#define CvDefParam_hpp__pyplusplus_wrapper

void register_CvDefParam_class();

#endif//CvDefParam_hpp__pyplusplus_wrapper
